@@ -1,3 +1,3 @@
-from EcoNameTranslator import EcoNameTranslator
+from .EcoNameTranslator import EcoNameTranslator
 import warnings
 warnings.filterwarnings("ignore")
